Module error

Module error 

REXX error types and error message formatting.

REXX defines specific error numbers (e.g., Error 41 = Bad arithmetic conversion). This module maps Rust error handling to REXX’s error numbering system while providing modern, helpful diagnostics.

Structs

RexxDiagnostic
A REXX runtime/parse error with location and context.
SourceLoc
Source location for error reporting.

Enums

RexxError
REXX error numbers per ANSI X3.274-1996 A. Not all are used initially but the numbering must be correct.

Type Aliases

RexxResult
Convenience alias.